Class: Resync::ChangeDump

Inherits:
Object
  • Object
show all
Includes:
Resync::Client::Mixins::Dump
Defined in:
lib/resync/client/mixins/dump.rb

Instance Method Summary collapse

Methods included from Resync::Client::Mixins::Dump

prepended, #resources=

Instance Method Details

#zip_packages(in_range: nil) ⇒ Array<Lazy::Promise<Resync::Client::Zip::ZipPackage>> Also known as: all_zip_packages

A list (downloaded lazily) of the Resync::Client::Zip::ZipPackages for each resource If a time range parameter is provided, the lists of packages is filtered by from_time and until_time, in non-strict mode (only excluding those lists provably not in the range, i.e., including packages without from_time or until_time).

Parameters:

  • in_range (Range<Time>) (defaults to: nil) —

    the range of times to filter by

Returns:



53
54
55
56
57
58
59
60
# File 'lib/resync/client/mixins/dump.rb', line 53

def zip_packages(in_range: nil)
  if in_range
    change_lists = change_lists(in_range: in_range, strict: false)
    change_lists.map { |r| Lazy.promise { r.zip_package } }
  else
    super()
  end
end