Module: Resync::Dump
- Included in:
- ChangeDump, ResourceDump
- Defined in:
- lib/resync/client/dump.rb
Overview
Extends ChangeDump and ResourceDump to provide transparent access to the linked bitstream packages
Instance Method Summary collapse
-
#resources=(value) ⇒ Object
Injects a
:zip_packagemethod into each resource, downloading the (presumed) bitstream package to a temp file and returning it as a ZipPackage. -
#zip_packages ⇒ ZipPackages
A list (downloaded lazily) of the ZipPackages for each resource.
Instance Method Details
#resources=(value) ⇒ Object
Injects a :zip_package method into each resource,
downloading the (presumed) bitstream package to a
temp file and returning it as a ZipPackage
10 11 12 13 14 15 16 17 |
# File 'lib/resync/client/dump.rb', line 10 def resources=(value) super resources.each do |r| def r.zip_package @zip_package ||= ZipPackage.new(download_to_temp_file) end end end |
#zip_packages ⇒ ZipPackages
A list (downloaded lazily) of the ZipPackages for each resource
21 22 23 |
# File 'lib/resync/client/dump.rb', line 21 def zip_packages @zip_packages ||= ZipPackages.new(resources) end |